# -*- coding: utf-8 -*-
from __future__ import annotations

from pygerber.parser.blender.apertures.rectangle import BlenderRectangle

# from pygerber.renderer.spec import ArcSpec, FlashSpec, LineSpec


class BlenderObround(BlenderRectangle):
    pass
